diff -pruN 3.70+nmu1/debian/changelog 3.71/debian/changelog
--- 3.70+nmu1/debian/changelog	2021-11-29 13:07:27.000000000 +0000
+++ 3.71/debian/changelog	2024-06-02 11:49:28.000000000 +0000
@@ -1,3 +1,34 @@
+mailcap (3.71) unstable; urgency=medium
+
+  [ Christian Göttsche ]
+  ea940af debian/postinst: set correct SELinux context for /etc/mailcap.
+
+  [ Julien Cristau ]
+  79285fc update-mime: convert .desktop file's TryExec to a
+          test= field for the mailcap entry (Closes: #964173)
+
+  [ Charles Plessy ]
+  4cccacb Re-allow program constants to be overridden by configuration files.
+          Thanks to Yair Yarom (Closes: #1005180)
+  e172852 run-mailcap: hardcode `file` path to /usr/bin/file.
+          Thanks again to Yair Yarom (Closes: #1071961)
+  675cf39 Update standards version to 4.7.0, no changes needed.
+  8332321 Fix use of two-font macros in manual pages.
+          Thanks to Bjarni Ingi Gislason (Closes: #935053, #935059)
+
+  [ Debian Janitor ]
+  bf52628 Update standards version to 4.6.1, no changes needed.
+
+  [ наб ]
+  14f3b5d run-mailcap: support zstd encoding (/.zstd?$/)
+
+  [ Max Nikulin ]
+  692501c update-mime: protect semicolons in Exec .desktop entries
+          (Closes: #1071036)
+
+
+ -- Charles Plessy <plessy@debian.org>  Sun, 02 Jun 2024 20:49:28 +0900
+
 mailcap (3.70+nmu1) unstable; urgency=medium
 
   * Non-maintainer upload.
@@ -73,7 +104,7 @@ mime-support (3.64) unstable; urgency=me
 mime-support (3.63) unstable; urgency=medium
 
   * Media types
-  
+
   7909e87 Add mjs suffix to application/javascript (Closes: #927300)
   ac860b6 Add application/ls+json            (Thanks: Nicolas Fella)
 
diff -pruN 3.70+nmu1/debian/control 3.71/debian/control
--- 3.70+nmu1/debian/control	2021-11-29 12:56:21.000000000 +0000
+++ 3.71/debian/control	2024-06-01 02:34:12.000000000 +0000
@@ -3,7 +3,7 @@ Maintainer: Mime-Support Packagers <team
 Uploaders: Charles Plessy <plessy@debian.org>
 Section: utils
 Priority: optional
-Standards-Version: 4.5.0
+Standards-Version: 4.7.0
 Vcs-Browser: https://salsa.debian.org/debian/mailcap
 Vcs-Git: https://salsa.debian.org/debian/mailcap.git
 
diff -pruN 3.70+nmu1/debian/postinst 3.71/debian/postinst
--- 3.70+nmu1/debian/postinst	2021-11-29 12:56:21.000000000 +0000
+++ 3.71/debian/postinst	2024-03-15 22:48:39.000000000 +0000
@@ -5,6 +5,8 @@ set -e
 # dpkg triggers support for update-mime
 if [ "$1" = "triggered" ]; then
     if command -v update-mime > /dev/null; then update-mime --triggered; fi
+    # Set correct SELinux context
+    if command -v restorecon >/dev/null 2>&1; then restorecon /etc/mailcap; fi
     exit 0
 fi
 
@@ -22,3 +24,5 @@ rm -f  /usr/sbin/install-mime
 
 # Run the update program
 if command -v update-mime > /dev/null; then update-mime --triggered; fi
+# Set correct SELinux context
+if command -v restorecon >/dev/null 2>&1; then restorecon /etc/mailcap; fi
diff -pruN 3.70+nmu1/run-mailcap 3.71/run-mailcap
--- 3.70+nmu1/run-mailcap	2021-11-29 12:56:21.000000000 +0000
+++ 3.71/run-mailcap	2024-06-01 02:28:10.000000000 +0000
@@ -44,8 +44,8 @@ sub Usage {
     print STDERR "  not specified, it will be determined from the filename extension\n\n";
     print STDERR "Encoding:\n";
     print STDERR "  how the file (and type) has been encoded (only \"gzip\", \"bzip2,\"\n";
-    print STDERR "  \"xz\" and \"compress\" are supported) -- if not specified, it will be\n";
-    print STDERR "   determined from the filename extension\n\n";
+    print STDERR "  \"xz\", \"zstd\", and \"compress\" are supported) -- if not specified,\n";
+    print STDERR "   it will be determined from the filename extension\n\n";
 
     exit ($error ? 1 : 0);
 }
@@ -56,10 +56,11 @@ sub EncodingForFile {
     my($file) = @_;
     my $encoding;
 
-    if ($file =~ m/\.gz$/)  { $encoding = "gzip";       }
-    if ($file =~ m/\.bz2$/) { $encoding = "bzip2";      }
-    if ($file =~ m/\.xz$/)  { $encoding = "xz";         }
-    if ($file =~ m/\.Z$/)   { $encoding = "compress";   }
+    if ($file =~ m/\.gz$/)    { $encoding = "gzip";       }
+    if ($file =~ m/\.bz2$/)   { $encoding = "bzip2";      }
+    if ($file =~ m/\.xz$/)    { $encoding = "xz";         }
+    if ($file =~ m/\.zstd?$/) { $encoding = "zstd";       }
+    if ($file =~ m/\.Z$/)     { $encoding = "compress";   }
 
     print STDERR " - file \"$file\" has encoding \"$encoding\"\n" if $debug && $encoding;
 
@@ -210,6 +211,12 @@ sub DecodeFile {
         } else {
             $res = system "xz -dc <\Q$efile\E >\Q$tmpfile\E";
         }
+    } elsif ($encoding eq "zstd") {
+        if ($efile eq '-') {
+            $res = system "zstd -dc >\Q$tmpfile\E";
+        } else {
+            $res = system "zstd -dc <\Q$efile\E >\Q$tmpfile\E";
+        }
     } elsif ($encoding eq "compress") {
         if ($efile eq '-') {
             $res = system "uncompress >\Q$tmpfile\E";
@@ -252,6 +259,12 @@ sub EncodeFile {
         } else {
             $res = system "xz < \Q$dfile\E >\Q$efile\E";
         }
+    } elsif ($encoding eq "zstd") {
+        if ($efile eq '-') {
+            $res = system "zstd -c < \Q$dfile\E";
+        } else {
+            $res = system "zstd -c < \Q$dfile\E >\Q$efile\E";
+        }
     } elsif ($encoding eq "compress") {
         if ($efile eq '-') {
             $res = system "compress <\Q$dfile\E";
@@ -298,8 +311,8 @@ sub MagicMimetype {
     my($file) = @_;
     my($typ);
 
-    if (`command -v file`) {
-        open(READER, "-|", "file", "-b", "--mime-type", "-e", "tokens", "-L", "-z", $file);
+    if (-x "/usr/bin/file") {
+        open(READER, "-|", "/usr/bin/file", "-b", "--mime-type", "-e", "tokens", "-L", "-z", $file);
         $typ = <READER>;
         chomp $typ;
         print STDERR " - file command returned mime-type \"$typ\"\n" if $debug;
diff -pruN 3.70+nmu1/run-mailcap.man 3.71/run-mailcap.man
--- 3.70+nmu1/run-mailcap.man	2021-11-29 12:56:21.000000000 +0000
+++ 3.71/run-mailcap.man	2024-06-02 08:07:30.000000000 +0000
@@ -41,7 +41,9 @@ are
 .B bzip2
 (.bz2),
 .B xz
-(.xz), and
+(.xz),
+.B zstd
+(.zst[d]), and
 .B compress
 (.Z).  A filename of "-" can be used to mean "standard input", but
 then a mime-type
@@ -58,11 +60,11 @@ Both the user's files (~/.mailcap; ~/.mi
 .SS OPTIONS
 All options are in the form --<opt>=<value>.
 .TP
-.BI \-\-action=<action>
+.BI \-\-action= <action>
 Performs the specified action on the files.  Valid actions are
 .IR view ,
-.IR cat
-(uses only "copiousoutput" rules and sends output to STDOUT) ,
+.I cat
+(uses only "copiousoutput" rules and sends output to STDOUT),
 .IR compose ,
 .IR composetyped ,
 .I edit
@@ -71,13 +73,13 @@ and
 If no action is specified, the action will be determined by how the
 program was called.
 .TP
-.BI \-\-debug
+.B \-\-debug
 Turns on extra information to find out what is happening.
 .TP
-.BI \-\-nopager
+.B \-\-nopager
 Ignores any "copiousoutput" directive and sends output to STDOUT.
 .TP
-.BI \-\-norun
+.B \-\-norun
 Displays the found command without actually executing it.
 .SH SECURITY
 A temporary symbolic link to the file is opened if the file name matches the Perl
Binary files 3.70+nmu1/schmurtz and 3.71/schmurtz differ
Binary files 3.70+nmu1/schmurtz.asfsdfa and 3.71/schmurtz.asfsdfa differ
diff -pruN 3.70+nmu1/update-mime 3.71/update-mime
--- 3.70+nmu1/update-mime	2021-11-29 12:58:25.000000000 +0000
+++ 3.71/update-mime	2024-06-02 03:23:05.000000000 +0000
@@ -21,16 +21,17 @@ use warnings;
 
 #
 # Program Constants
+# They can be overridden in $conffile, except of course $conffile itself
 #
-my $debug	= 0;
-my $conffile	= "/etc/update-mime.conf";
-my $mailcap	= "/etc/mailcap";
-my $mailcapdef	= "/usr/lib/mime/mailcap";
-my $mimedir	= "/usr/lib/mime/packages";
-my $appsdir	= "/usr/share/applications";
-my $orderfile	= "/etc/mailcap.order";
-my $defpriority	= 5;
-my $localgen	= 0;
+our $debug       = 0;
+my  $conffile    = "/etc/update-mime.conf";
+our $mailcap     = "/etc/mailcap";
+our $mailcapdef  = "/usr/lib/mime/mailcap";
+our $mimedir     = "/usr/lib/mime/packages";
+our $appsdir     = "/usr/share/applications";
+our $orderfile   = "/etc/mailcap.order";
+our $defpriority = 5;
+our $localgen    = 0;
 
 
 # If the call comes from dpkg, only accept it if --triggered is passed
@@ -141,7 +142,7 @@ sub ReadDesktopEntries
 		$packages{$pkg} = [];
 
 		if (open(FILE,"<$file")) {
-			my($terminal, $name, $icon, $exec, @types) = ("test=test -n \"\$DISPLAY\"", $pkg);
+			my($name, $icon, $exec, $terminal, $test, @types) = ($pkg);
 			my $in_desktop_group = 0;
 			while (<FILE>) {
 				chomp;
@@ -164,11 +165,15 @@ sub ReadDesktopEntries
 				elsif (m/^Icon=(.+)/i) {
 					$icon = $1;
 				}
-				elsif (m/Exec=(.*)$/i) {
+				elsif (m/^Exec=(.*)$/i) {
 					$exec = $1;
+					$exec =~ s/((?:\\\\)*)\\?(;)/$1\\$2/g;
 					$exec =~ s/%[fFuU]/%s/g;
 					$exec .= " %s" if ($exec !~ m/%s/);
 				}
+				elsif (m/^TryExec=(.*)/i) {
+					$test = "test=command -v $1";
+				}
 				elsif (m/MimeType=(.*)/i) {
 					my $err = 0;
 					push @types, grep { if (length>0) {1} else {++$err;0} }
@@ -180,6 +185,15 @@ sub ReadDesktopEntries
 				close(FILE);
 				next;
 			}
+			if (!defined($terminal)) {
+				if (defined($test)) {
+					$terminal = "$test && test -n \"\$DISPLAY\"";
+				} else {
+					$terminal = "test=test -n \"\$DISPLAY\"";
+				}
+			} elsif (defined($test)) {
+				$terminal .= "; $test";
+			}
 			$exec =~ s/%c/$name/g;
 			$exec =~ s/%i/--icon $icon/g;
 			foreach my $type (@types) {
diff -pruN 3.70+nmu1/update-mime.man 3.71/update-mime.man
--- 3.70+nmu1/update-mime.man	2021-11-29 12:56:21.000000000 +0000
+++ 3.71/update-mime.man	2024-06-02 08:11:52.000000000 +0000
@@ -17,7 +17,7 @@ file to reflect mime information changed
 installation or removal.
 
 .SS OPTIONS
-.BI \-\-local
+.B \-\-local
 Generate files in the current user's home directory instead of the
 .I /etc
 directory.  This allows users to create a custom ordering configuration and get
@@ -34,7 +34,7 @@ The order of entries in the
 file can be altered by editing the
 .I /etc/mailcap.order
 file.  Please see the
-.BR mailcap.order(5)
+.BR mailcap.order (5)
 man page for more information.
 
 .SH CREATING ENTRIES
@@ -67,7 +67,7 @@ rules using the default priority will ge
 that rule a "last resort".
 .SS Commands
 .TP
-.BI <program-string>
+.B <program-string>
 Specifies the program to run to view a file of the given content-type.
 .B This option setting cannot be omitted.
 An implicit "view=" can be considered before it.  When writing an
@@ -75,7 +75,7 @@ entry that has no viewer, use a value of
 .I false
 in this space.
 .TP
-.BI compose=<program-string>
+.BI compose= <program-string>
 The "compose" command may be used to specify a program that can be
 used to compose a new body or body part in the given format.  Its
 intended use is to support mail composing agents that support the
@@ -84,7 +84,7 @@ The result of the composing program may
 suitable for mail transport -- that is, a Content-Transfer-Encoding
 may need to be applied to the data.
 .TP
-.BI composetyped=<program-string>
+.BI composetyped= <program-string>
 The "composetyped" command is similar to "compose", but is to be used
 when the composing program needs to specify the Content-type header
 field to be applied to the composed data.  The "compose" option is
@@ -95,19 +95,19 @@ auxiliary parameters, and the compositio
 enough about mail formats to produce output that includes the mail
 type information.
 .TP
-.BI edit=<program-string>
+.BI edit= <program-string>
 The "edit" command may be used to specify a program that can be used
 to edit a body or body part in the given format.  In many cases, it
 may be identical in content to the "compose" command.
 .TP
-.BI print=<program-string>
+.BI print= <program-string>
 The "print" command may be used to specify a program that can be used to
 print a message or body part in the given format.
 .SS Modifiers
 These options are modifiers to all the commands specified on the
 command line.
 .TP
-.BI test=<conditional>
+.BI test= <conditional>
 The "test" option may be used to test some external condition (e.g.,
 the machine architecture, or the window system in use) to determine
 whether or not the mailcap line applies.  It specifies a program to be
@@ -126,7 +126,7 @@ environment variable, please use one of:
 
 Many programs recognize these strings and optimize for them.
 .TP
-.BI needsterminal
+.B needsterminal
 The "needsterminal" option, if given, indicates that the commands must
 be run on an interactive terminal.  This is needed to inform window-oriented
 user agents that an interactive terminal is needed.  (The decision is
@@ -139,7 +139,7 @@ will be executed, and will typically cau
 window when not executed on either a real terminal or a terminal
 window.
 .TP
-.BI copiousoutput
+.B copiousoutput
 The "copiousoutput" option, if given, indicates that the output from the
 view-command will be an extended stream of output and is to be
 interpreted as advice to the UA (User Agent mail-reading program) that
@@ -150,12 +150,12 @@ specified.
 These options provide additional information about the given
 content-type.
 .TP
-.BI description=<string>
+.B description=<string>
 The "description" option simply provides a textual description that
 describes the type of data, to be used optionally by mail readers that
 wish to describe the data before offering to display it.
 .TP
-.BI textualnewlines
+.B textualnewlines
 The "textualnewlines" option, if given, indicates that this type
 of data is line-oriented and that, if encoded in a binary format, all
 newlines should be converted to canonical form (CRLF) before encoding,
@@ -163,12 +163,12 @@ and will be in that form after decoding.
 only if there is line-oriented data of some type other than text/* or
 non-line-oriented data that is a subtype of text.
 .TP
-.BI x11-bitmap=<pathname>
+.BI x11-bitmap= <pathname>
 The "x11-bitmap" option names a file, in X11 bitmap (xbm) format,
 which points to an appropriate icon to be used to visually denote the
 presence of this kind of data.
 .TP
-.BI nametemplate=<string>
+.BI nametemplate= <string>
 The "nametemplate" option gives a file name format, in which %s will be
 replaced by a short unique string to give the name of the temporary
 file to be passed to the viewing command.  This is only expected to be
